@@ -592,86 +592,6 @@ class EndpointPipelinePublisher:
             published_endpoint = published_pipeline.endpoint
             
         return published_endpoint
-        
-class WebServiceDeployer:
-    def __init__(self, ws):
-        self.ws = ws
-        self.aciconfig = AciWebservice.deploy_configuration(cpu_cores=1, 
-                                                    memory_gb=1, 
-                                                    tags={"data": "Disaster-data",  "method" : "torch"}, 
-                                                    description='Predict Disaster with torch')
-        myenv = Environment.from_conda_specification(name="myenv", file_path="myenv.yml")
-        self.inference_config = InferenceConfig(entry_script="score.py", environment=myenv)
-
-    def deploy(self):
-        myenv = CondaDependencies()                                                        
-        myenv.add_pip_package("azureml-sdk")
-        myenv.add_pip_package("torch")
-        #myenv.add_pip_package("torch")
-        myenv.add_pip_package("torchvision")
-        myenv.add_pip_package("azureml-dataprep[pandas,fuse]>=1.1.14")
-
-        with open("myenv.yml","w") as f:
-            f.write(myenv.serialize_to_string())
-
-        #Create a deployment configuration file and specify the number of CPUs and gigabyte 
-        # of RAM needed for ACI container.
-        #aciconfig = AciWebservice.deploy_configuration(cpu_cores=1, 
-        #                                            memory_gb=1, 
-        #                                            tags={"data": "Disaster-data",  "method" : "torch"}, 
-        #                                            description='Predict Disaster with torch')
-
-
-        #myenv = Environment.from_conda_specification(name="myenv", file_path="myenv.yml")
-        #inference_config = InferenceConfig(entry_script="score.py", environment=myenv)
-
-        try:
-            AciWebservice(self.ws, AllConstants.SERVICE_NAME).delete()
-        except WebserviceException:
-            pass
-
-        model = self.ws.models[AllConstants.MODEL_NAME]
-        
-
-        service = Model.deploy(workspace=self.ws, 
-                            name=AllConstants.SERVICE_NAME, 
-                            models=[model], 
-                            inference_config=self.inference_config, 
-                            deployment_config=self.aciconfig)
-        
-        service.wait_for_deployment(show_output=True)
-        
-    
-    def test(self):
-        service = AciWebservice(self.ws, AllConstants.SERVICE_NAME)
-        #print(type(service))
-        #scoring_uri = service.scoring_uri
-        #headers = {'Content-Type':'application/json'}
-        print(service.get_logs())
-        test_data = json.dumps({'data': 'Today is a great day!'})
-
-        # Call the web service, passing the input data (the web service will also accept the data in binary format)
-        predictions = service.run(input_data = test_data)
-
-        # Get the predicted class - it'll be the first (and only) one.
-        predicted_classes = json.loads(predictions)
-        print(predicted_classes[0])
-
-        #response = requests.post(scoring_uri, data=test_data, headers=headers)
-        #print(response.status_code)
-        #print(response.elapsed)
-        #print(response.json())
-class AllConstants:
-    BLOB_STORAGE_CONNECTION_STRING = "DefaultEndpointsProtocol=https;AccountName=humlstorage;AccountKey=InGUfK++98C0tANJqmP3AbV5tTMpDj+5XikesQpjYWSH1MYxAspw5sbmfMcmMPgBGpYHVGuGtuEuGAICu3zFlw==;EndpointSuffix=core.windows.net"
-    EXPERIMENT_NAME = "huml_experiment"
-    MODEL_NAME = "huml_model"
-    #PIPELINE_NAME = "huml_pipeline"
-    PIPELINE_NAME = "huml_pipeline"
-    SERVICE_NAME = "huml-svc"
-    EXPERIMENT_SAMPLING_NAME = "huml-sampling-experiment"
-    PIPELINE_SAMPLING = "huml_sampling_pipeline"
-    SCHEDULER_CURRENT_ANNOTATED_DATA = "scheduler_current_annotated_data"
-    CURRENT_ANNOTATED_DATA_PATH = "annotated_data/current"
 
 class LogicAppPipelineConfigManager:
     def __init__(self, config):
@@ -1105,6 +1025,9 @@ class ConfigProvider:
         self.PIPELINE_SAMPLING_ENDPOINT = data["Azure"]["Azureml"]["Pipelines"]["Sampling"]["EndPoint"]
         #Model
         self.MODEL_NAME = data["Azure"]["Azureml"]["Model"]["Name"]
+        #Deploy
+        self.DEPLOY_SERVICE_NAME = data["Azure"]["Azureml"]["Deploy"]["ServiceName"]
+        self.DEPLOY_THRESHOLD =  data["Azure"]["Azureml"]["Deploy"]["ModelThreshold"]
 
         #ServicePrincipalAuthentication
         self.SPA_TENANTID = data["Azure"]["ServicePrincipalAuthentication"]["TenantId"]
